dask-awkward
============

> Connecting [awkward-array](https://awkward-array.org) and
[Dask](https://dask.org/).

[![Tests](https://github.com/dask-contrib/dask-awkward/actions/workflows/pypi-tests.yml/badge.svg)](https://github.com/dask-contrib/dask-awkward/actions/workflows/pypi-tests.yml)
[![Tests](https://github.com/dask-contrib/dask-awkward/actions/workflows/conda-tests.yml/badge.svg)](https://github.com/dask-contrib/dask-awkward/actions/workflows/conda-tests.yml)
[![Documentation Status](https://readthedocs.org/projects/dask-awkward/badge/?version=latest)](https://dask-awkward.readthedocs.io/en/latest/?badge=latest)
[![Coverage](https://codecov.io/gh/dask-contrib/dask-awkward/branch/main/graph/badge.svg)](https://codecov.io/gh/dask-contrib/dask-awkward/branch/main)
[![PyPI](https://img.shields.io/pypi/v/dask-awkward?color=blue)](https://pypi.org/project/dask-awkward)
[![Conda Forge](https://img.shields.io/conda/vn/conda-forge/dask-awkward.svg?colorB=486b87&style=flat)](https://anaconda.org/conda-forge/dask-awkward)

Installing
----------

Releases are available from PyPI and conda-forge.

PyPI:

```
pip install dask-awkward
```

conda-forge:

```
conda install dask-awkward -c conda-forge
```

Documentation
-------------

Documentation is hosted at
[https://dask-awkward.readthedocs.io/](https://dask-awkward.readthedocs.io/).
